searchData={"items":[{"type":"module","title":"OpentelemetryBandit","doc":"OpenTelemetry instrumentation for Bandit.","ref":"OpentelemetryBandit.html"},{"type":"module","title":"Semantic Conventions - OpentelemetryBandit","doc":"All required and recommended Server HTTP Span semantic conventions are implemented.\nSupported opt-in attributes can be configured using the `opt_in_attrs` option.","ref":"OpentelemetryBandit.html#module-semantic-conventions"},{"type":"module","title":"Options - OpentelemetryBandit","doc":"","ref":"OpentelemetryBandit.html#module-options"},{"type":"module","title":"Opt-in Semantic Convention Attributes - OpentelemetryBandit","doc":"Otel SemConv requires users to explicitly opt in for any attribute with a\nrequirement level of `opt-in`. To ensure compatability, always use the\nSemConv attribute.\n\nExample:\n```\nopt_ins = [SemConv.HTTPAttributes.http_request_body_size()]`\nOpentelemetryBandit.setup(opt_in_attrs: opt_ins)\n```\n\n#### Request and Response Headers as Opt-in Attributes\n\nRequest and response header attributes are opt-in and can be set with the\n`request_headers` and `response_headers` options. Values should be lower-case.\n\n```\nOpentelemetryBandit.setup(request_headers: [\"x-customer-id\"])\n```","ref":"OpentelemetryBandit.html#module-opt-in-semantic-convention-attributes"},{"type":"module","title":"Public Endpoint - OpentelemetryBandit","doc":"Setting an endpoint as public will result in any propagated trace to be added as a link,\nrather than a continuation of an existing trace. The `public_endpoint` option should be set\nto `true` if an endpoint only accepts public traffic to prevent missing root spans. By default,\nthe endpoint is handled as non-public, resulting in traces being continued rather than linked.\n\nIn a mixed traffic environment, an MFA can be supplied to determine whether to\ntreat a request as public. This function is executed on every request, so refrain\nfrom expensive operations such as lookups to external systems. The function must\nbe a predicate function of arity-2, accepting the `conn` from the request as\nthe first argument and user-supplied options as the second. Any dynamic\ninformation used in comparisons should be supplied at setup time for efficiency.\n\nExample:\n```\ndefmodule PublicEndpoint do\n  def is_public_request?(conn, opts) do\n    # return true if request was public\n  end\nend\n\nOpentelemetryBandit.setup(public_endpoint_fn: {PublicEndpoint, :is_public_request?, []})\n```","ref":"OpentelemetryBandit.html#module-public-endpoint"},{"type":"function","title":"OpentelemetryBandit.setup/1","doc":"Initializes and configures the telemetry handlers.\n\nSupported options:\n* `:opt_in_attrs` - Use semantic conventions library to ensure compatability, e.g. `[HTTPAttributes.http_request_body_size()]`\n\n    * `:\"client.port\"`\n\n    * `:\"http.request.body.size\"`\n\n    * `:\"http.response.body.size\"`\n\n    * `:\"network.local.address\"`\n\n    * `:\"network.local.port\"`\n\n    * `:\"network.transport\"`\n\n  The default value is `[]`.\n\n* `:handler_id` (`t:atom/0`) - Only set when running multiple instances on different endpoints The default value is `:otel_bandit`.\n\n* `:client_address_headers` (list of `t:String.t/0`) - Headers to use for extracting original client request address info The default value is `[\"forwarded\", \"x-forwarded-for\"]`.\n\n* `:client_headers_sort_fn` (function of arity 2) - Custom client header sort fn. See `otel_http` for more info\n\n* `:public_endpoint` (`t:boolean/0`) - Endpoint is public. Propagated traces will be added as a link. The default value is `false`.\n\n* `:public_endpoint_fn` - Default function returns `false`. See docs for more info The default value is `{OpentelemetryBandit, :default_public_endpoint_fn, []}`.\n\n* `:request_headers` (list of `t:String.t/0`) - List of request headers to add as attributes. (lowercase) The default value is `[]`.\n\n* `:response_headers` (list of `t:String.t/0`) - List of response headers to add as attributes. (lowercase) The default value is `[]`.\n\n* `:scheme_headers` (list of `t:String.t/0`) - Headers to use for extracting original client request scheme The default value is `[\"forwarded\", \"x-forwarded-proto\"]`.\n\n* `:scheme_headers_sort_fn` (function of arity 2) - Custom scheme header sort fn. See `otel_http` for more info\n\n* `:server_address_headers` (list of `t:String.t/0`) - Headers to use for extracting original server address info The default value is `[\"forwarded\", \"x-forwarded-host\", \"host\"]`.\n\n* `:server_headers_sort_fn` (function of arity 2) - Custom server header sort fn. See `otel_http` for more info","ref":"OpentelemetryBandit.html#setup/1"},{"type":"type","title":"OpentelemetryBandit.opt_in_attr/0","doc":"Use semantic conventions library to ensure compatability, e.g. `HTTPAttributes.http_request_body_size()`","ref":"OpentelemetryBandit.html#t:opt_in_attr/0"},{"type":"type","title":"OpentelemetryBandit.opt_in_attrs/0","doc":"","ref":"OpentelemetryBandit.html#t:opt_in_attrs/0"},{"type":"type","title":"OpentelemetryBandit.options/0","doc":"","ref":"OpentelemetryBandit.html#t:options/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}